@@ -12,10 +12,11 @@ our @EXPORT = qw(
 	&assert
 );
 use vars qw/$VERSION/;
-$VERSION = '1.20';
+$VERSION = '1.21';
 
 use Carp qw/croak carp/;
 
+
 sub assert {
 }
 
@@ -68,6 +69,11 @@ production without refactoring your code.
 
 Exports the 'assert' subroutine to the caller's namespace.
 
+=head2 assert
+
+The implementation of the assert subroutine exported by this
+package is a no-op.
+
 =head1 AUTHOR
 
 Steffen Mueller E<lt>assert-module at steffen-mueller dot netE<gt>
